@@ -88,6 +88,15 @@ class AdapterTask(Task):
     def input_transform(self, input_transform: INPUT_TRANSFORM_TYPE) -> None:
         self.adapter.input_transform = input_transform
 
+    @torch.jit.unused
+    @property
+    def collate_fn(self) -> Optional[Callable]:
+        return self.adapter.collate_fn
+
+    @collate_fn.setter
+    def collate_fn(self, collate_fn: Callable) -> None:
+        self.adapter.collate_fn = collate_fn
+
     @torch.jit.unused
     @property
     def backbone(self) -> nn.Module:
