@@ -242,7 +242,9 @@ class DataModule(pl.LightningDataModule):
         else:
             sampler = self.sampler
 
-        if isinstance(getattr(self, "trainer", None), pl.Trainer):
+        if isinstance(getattr(self, "trainer", None), pl.Trainer) and hasattr(
+            self.trainer.lightning_module, "process_train_dataset"
+        ):
             dataloader = self.trainer.lightning_module.process_train_dataset(
                 train_ds,
                 trainer=self.trainer,
@@ -290,7 +292,9 @@ class DataModule(pl.LightningDataModule):
             transform_processor = collate_fn
             collate_fn = transform_processor.collate_fn
 
-        if isinstance(getattr(self, "trainer", None), pl.Trainer):
+        if isinstance(getattr(self, "trainer", None), pl.Trainer) and hasattr(
+            self.trainer.lightning_module, "process_val_dataset"
+        ):
             dataloader = self.trainer.lightning_module.process_val_dataset(
                 val_ds,
                 trainer=self.trainer,
@@ -332,7 +336,9 @@ class DataModule(pl.LightningDataModule):
             transform_processor = collate_fn
             collate_fn = transform_processor.collate_fn
 
-        if isinstance(getattr(self, "trainer", None), pl.Trainer):
+        if isinstance(getattr(self, "trainer", None), pl.Trainer) and hasattr(
+            self.trainer.lightning_module, "process_test_dataset"
+        ):
             dataloader = self.trainer.lightning_module.process_test_dataset(
                 test_ds,
                 trainer=self.trainer,
@@ -379,7 +385,9 @@ class DataModule(pl.LightningDataModule):
         else:
             batch_size = min(self.batch_size, len(predict_ds) if len(predict_ds) > 0 else 1)
 
-        if isinstance(getattr(self, "trainer", None), pl.Trainer):
+        if isinstance(getattr(self, "trainer", None), pl.Trainer) and hasattr(
+            self.trainer.lightning_module, "process_predict_dataset"
+        ):
             dataloader = self.trainer.lightning_module.process_predict_dataset(
                 predict_ds,
                 batch_size=batch_size,
