@@ -27,6 +27,11 @@ class ClassificationInputMixin(Properties):
       tasks.
     """
 
+    target_formatter: TargetFormatter
+    multi_label: bool
+    labels: list
+    num_classes: int
+
     def load_target_metadata(
         self,
         targets: Optional[List[Any]],
@@ -60,6 +65,4 @@ class ClassificationInputMixin(Properties):
         Returns:
             The formatted target.
         """
-        if getattr(self, "target_formatter", None) is not None:
-            return self.target_formatter(target)
-        return target
+        return getattr(self, "target_formatter", lambda x: x)(target)
