@@ -4,7 +4,8 @@ from flash.image.classification import (  # noqa: F401
     ImageClassifier,
 )
 from flash.image.classification.backbones import IMAGE_CLASSIFIER_BACKBONES  # noqa: F401
-from flash.image.detection import ObjectDetectionData, ObjectDetector  # noqa: F401
+from flash.image.detection.data import ObjectDetectionData  # noqa: F401
+from flash.image.detection.model import ObjectDetector  # noqa: F401
 from flash.image.embedding import ImageEmbedder  # noqa: F401
 from flash.image.face_detection import FaceDetectionData, FaceDetector  # noqa: F401
 from flash.image.instance_segmentation import InstanceSegmentation, InstanceSegmentationData  # noqa: F401
